@@ -270,8 +270,8 @@ impl HasHelpView for story_view::StoryView {
                         "Go the previous page",
                     ),
                     Command::new(
-                        story_view_keymap.toggle_sort_by_date.to_string(),
-                        "Toggle sort by date (only for non `Front Page` views)",
+                        story_view_keymap.cycle_sort_mode.to_string(),
+                        "Cycle story sort mode (not for `front_page` story views)",
                     ),
                 ],
             ),
@@ -426,10 +426,16 @@ impl HasHelpView for comment_view::CommentView {
             CommandGroup::new(
                 "Others",
                 [
-                    vec![Command::new(
-                        comment_view_keymap.toggle_collapse_comment.to_string(),
-                        "Toggle collapsing the focused comment",
-                    )],
+                    vec![
+                        Command::new(
+                            comment_view_keymap.toggle_collapse_comment.to_string(),
+                            "Toggle collapsing the focused item",
+                        ),
+                        Command::new(
+                            comment_view_keymap.vote.to_string(),
+                            "Toggle voting the focused item",
+                        ),
+                    ],
                     default_other_commands(),
                 ]
                 .concat(),
@@ -486,8 +492,8 @@ impl HasHelpView for search_view::SearchView {
                         "Go the previous page",
                     ),
                     Command::new(
-                        story_view_keymap.toggle_sort_by_date.to_string(),
-                        "Toggle sort by date",
+                        story_view_keymap.cycle_sort_mode.to_string(),
+                        "Cycle story sort mode",
                     ),
                 ],
             ),
